==> jc-1.4.0.tar.gz: javax/swing/tree/ExpandVetoException.h <==
// public class javax.swing.tree.ExpandVetoException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 99cf735766207ffa javax_swing_tree_ExpandVetoException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_javax_swing_tree_ExpandVetoException_H_
#define _JC_javax_swing_tree_ExpandVetoException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_event_TreeExpansionEvent$object;

// Typedefs
typedef struct _jc_javax_swing_tree_ExpandVetoException$sub_refs	_jc_javax_swing_tree_ExpandVetoException$sub_refs;
typedef struct _jc_javax_swing_tree_ExpandVetoException$sub_nonrefs	_jc_javax_swing_tree_ExpandVetoException$sub_nonrefs;
typedef struct _jc_javax_swing_tree_ExpandVetoException$refs	_jc_javax_swing_tree_ExpandVetoException$refs;
typedef struct _jc_javax_swing_tree_ExpandVetoException$nonrefs	_jc_javax_swing_tree_ExpandVetoException$nonrefs;
typedef struct _jc_javax_swing_tree_ExpandVetoException$object	_jc_javax_swing_tree_ExpandVetoException$object;

typedef const struct _jc_javax_swing_tree_ExpandVetoException$vmethods	_jc_javax_swing_tree_ExpandVetoException$vmethods;
typedef const struct _jc_javax_swing_tree_ExpandVetoException$vtable	_jc_javax_swing_tree_ExpandVetoException$vtable;
typedef const struct _jc_javax_swing_tree_ExpandVetoException$vtype	_jc_javax_swing_tree_ExpandVetoException$vtype;

// Constructors
extern void _jc_javax_swing_tree_ExpandVetoException$method$_init$af34e105c0df2e2c(_jc_env *, struct _jc_javax_swing_tree_ExpandVetoException$object *, struct _jc_javax_swing_event_TreeExpansionEvent$object *);
extern void _jc_javax_swing_tree_ExpandVetoException$method$_init$71533db51871e7a9(_jc_env *, struct _jc_javax_swing_tree_ExpandVetoException$object *, struct _jc_javax_swing_event_TreeExpansionEvent$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_javax_swing_tree_ExpandVetoException$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_tree_ExpandVetoException$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_tree_ExpandVetoException$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_swing_tree_ExpandVetoException$vmethods {
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_tree_ExpandVetoException$object *);
};

// Vtable
struct _jc_javax_swing_tree_ExpandVetoException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_swing_tree_ExpandVetoException$vmethods	javax_swing_tree_ExpandVetoException;
};

// Vtype
struct _jc_javax_swing_tree_ExpandVetoException$vtype {
	_jc_type			type;
	_jc_javax_swing_tree_ExpandVetoException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_tree_ExpandVetoException$sub_refs {
	struct _jc_javax_swing_event_TreeExpansionEvent$object	*event;
};

// Reference instance fields (object)
struct _jc_javax_swing_tree_ExpandVetoException$refs {
    _jc_javax_swing_tree_ExpandVetoException$sub_refs	javax_swing_tree_ExpandVetoException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_tree_ExpandVetoException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_tree_ExpandVetoException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_swing_tree_ExpandVetoException$sub_nonrefs	javax_swing_tree_ExpandVetoException;
};

// Object instance structure
struct _jc_javax_swing_tree_ExpandVetoException$object {
	_jc_javax_swing_tree_ExpandVetoException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_tree_ExpandVetoException$vtype	*vtype;
	_jc_javax_swing_tree_ExpandVetoException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_tree_ExpandVetoException$vtype _jc_javax_swing_tree_ExpandVetoException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_tree_ExpandVetoException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_tree_ExpandVetoException$class_object;

#endif	/* _JC_javax_swing_tree_ExpandVetoException_H_ */

==> jc-1.4.6.tar.gz: javax/swing/tree/ExpandVetoException.h <==
// public class javax.swing.tree.ExpandVetoException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 99cf735766207ffa javax_swing_tree_ExpandVetoException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_javax_swing_tree_ExpandVetoException_H_
#define _JC_javax_swing_tree_ExpandVetoException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_event_TreeExpansionEvent$object;

// Typedefs
typedef struct _jc_javax_swing_tree_ExpandVetoException$sub_refs	_jc_javax_swing_tree_ExpandVetoException$sub_refs;
typedef struct _jc_javax_swing_tree_ExpandVetoException$sub_nonrefs	_jc_javax_swing_tree_ExpandVetoException$sub_nonrefs;
typedef struct _jc_javax_swing_tree_ExpandVetoException$refs	_jc_javax_swing_tree_ExpandVetoException$refs;
typedef struct _jc_javax_swing_tree_ExpandVetoException$nonrefs	_jc_javax_swing_tree_ExpandVetoException$nonrefs;
typedef struct _jc_javax_swing_tree_ExpandVetoException$object	_jc_javax_swing_tree_ExpandVetoException$object;

typedef const struct _jc_javax_swing_tree_ExpandVetoException$vmethods	_jc_javax_swing_tree_ExpandVetoException$vmethods;
typedef const struct _jc_javax_swing_tree_ExpandVetoException$vtable	_jc_javax_swing_tree_ExpandVetoException$vtable;
typedef const struct _jc_javax_swing_tree_ExpandVetoException$vtype	_jc_javax_swing_tree_ExpandVetoException$vtype;

// Constructors
extern void _jc_javax_swing_tree_ExpandVetoException$method$_init$af34e105c0df2e2c(_jc_env *, struct _jc_javax_swing_tree_ExpandVetoException$object *, struct _jc_javax_swing_event_TreeExpansionEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_tree_ExpandVetoException$method$_init$71533db51871e7a9(_jc_env *, struct _jc_javax_swing_tree_ExpandVetoException$object *, struct _jc_javax_swing_event_TreeExpansionEvent$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_tree_ExpandVetoException$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_tree_ExpandVetoException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_tree_ExpandVetoException$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_swing_tree_ExpandVetoException$vmethods {
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_tree_ExpandVetoException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_tree_ExpandVetoException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_swing_tree_ExpandVetoException$vmethods	javax_swing_tree_ExpandVetoException;
};

// Vtype
struct _jc_javax_swing_tree_ExpandVetoException$vtype {
	_jc_type			type;
	_jc_javax_swing_tree_ExpandVetoException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_tree_ExpandVetoException$sub_refs {
	struct _jc_javax_swing_event_TreeExpansionEvent$object	*event;
};

// Reference instance fields (object)
struct _jc_javax_swing_tree_ExpandVetoException$refs {
    _jc_javax_swing_tree_ExpandVetoException$sub_refs	javax_swing_tree_ExpandVetoException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_tree_ExpandVetoException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_tree_ExpandVetoException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_swing_tree_ExpandVetoException$sub_nonrefs	javax_swing_tree_ExpandVetoException;
};

// Object instance structure
struct _jc_javax_swing_tree_ExpandVetoException$object {
	_jc_javax_swing_tree_ExpandVetoException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_tree_ExpandVetoException$vtype	*vtype;
	_jc_javax_swing_tree_ExpandVetoException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_tree_ExpandVetoException$vtype _jc_javax_swing_tree_ExpandVetoException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_tree_ExpandVetoException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_tree_ExpandVetoException$class_object;

#endif	/* _JC_javax_swing_tree_ExpandVetoException_H_ */
